# pspm

pspm is Python's Simplest Package Manager.

![logo-pspm](https://github.com/user-attachments/assets/6a35d219-1193-42f8-a1b6-0331818e8e4d)

<div align="center">

[![Docs](https://img.shields.io/badge/docs-mkdocs-blue?style=for-the-badge)](https://jahn16.github.io/pspm/)
[![PyPI - Version](https://img.shields.io/pypi/v/pspm?logo=python&style=for-the-badge)](https://pypi.org/project/pspm/)
![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/Jahn16/pspm/test.yaml?label=tests&logo=github&style=for-the-badge)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=for-the-badge)](https://github.com/astral-sh/ruff)
</div>

## Installation

I recommend using [pipx](https://pipx.pypa.io/stable/) to install pspm.

```bash
pipx install pspm
```

## Quickstart
### Install packages
```bash
spm add -g dev pytest
```

## Roadmap
### Comands
- [x] Init
- [x] Install
- [x] Add
- [x] Remove
- [x] Run
- [x] Lock
- [x] Version

## License

Licensed under the [GNU GPLv3](LICENSE) license.
